# Copyright (c) 2024 Radin Abdorazaghi
# All rights reserved.
#
# This software is the confidential and proprietary information of Radin Abdorazaghi.
# You shall not disclose such Confidential Information and shall use it only in accordance
# with the terms of the license agreement you entered into with Radin Abdorazaghi.
#
# Unauthorized copying of this file, via any medium is strictly prohibited.
# Proprietary and confidential.
